==> haskell-tasty-lua-1.1.1.1-65.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-lua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-lua
version:              1.1.1.1
visibility:           public
id:                   tasty-lua-1.1.1.1-4Qv0MmiCLUUJwfjmFppnhk
key:                  tasty-lua-1.1.1.1-4Qv0MmiCLUUJwfjmFppnhk
license:              MIT
copyright:            © 2019-2025 Albert Krewinkel <tarleb@hslua.org>
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Write tests in Lua, integrate into tasty.
description:          Allow users to define tasty tests from Lua.
category:             Foreign
abi:                  82216d59852dd465273d5e97b13bb899
exposed:              True
exposed-modules:
    Test.Tasty.Lua Test.Tasty.Lua.Arbitrary Test.Tasty.Lua.Core
    Test.Tasty.Lua.Module Test.Tasty.Lua.Translate

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-lua-1.1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-lua-1.1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-lua-1.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-lua
hs-libraries:         HStasty-lua-1.1.1.1-4Qv0MmiCLUUJwfjmFppnhk
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1
    bytestring-0.11.5.3 file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    hslua-core-2.3.2-LsuRv5joEv2BEnjW1fCbrM
    hslua-marshalling-2.3.1-2wvb5zI3Ais62iyLUWMiUH
    lua-arbitrary-1.0.1.1-KKuCXfS60IwIoVaZfDNsPU
    tasty-1.5.2-K3PchMZYxV2JdxeMIpuhjP

haddock-interfaces:   /usr/share/doc/haskell-tasty-lua/html/tasty-lua.haddock
haddock-html:         /usr/share/doc/haskell-tasty-lua/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-lua-1.1.1.1-66-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-lua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-lua
version:              1.1.1.1
visibility:           public
id:                   tasty-lua-1.1.1.1-5s84aVEDHVz2pw6DT6uHQ6
key:                  tasty-lua-1.1.1.1-5s84aVEDHVz2pw6DT6uHQ6
license:              MIT
copyright:            © 2019-2025 Albert Krewinkel <tarleb@hslua.org>
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Write tests in Lua, integrate into tasty.
description:          Allow users to define tasty tests from Lua.
category:             Foreign
abi:                  6e220824088d29d1bc531b5e6b5f064d
exposed:              True
exposed-modules:
    Test.Tasty.Lua Test.Tasty.Lua.Arbitrary Test.Tasty.Lua.Core
    Test.Tasty.Lua.Module Test.Tasty.Lua.Translate

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-lua-1.1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-lua-1.1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-lua-1.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-lua
hs-libraries:         HStasty-lua-1.1.1.1-5s84aVEDHVz2pw6DT6uHQ6
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    bytestring-0.11.5.3 file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    hslua-core-2.3.2-6IHXwFbRgmjH5Bn36TUerg
    hslua-marshalling-2.3.1-Lphd68rczTTD9xcjuNYtYD
    lua-arbitrary-1.0.1.1-HdPQa4xv73L5adVXSRuKup
    tasty-1.5.2-C3yI3pzTEHWEDVqwlNW4dB

haddock-interfaces:   /usr/share/doc/haskell-tasty-lua/html/tasty-lua.haddock
haddock-html:         /usr/share/doc/haskell-tasty-lua/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
